@@ -187,11 +187,13 @@ def reconciled(product):
     if not product:
         fuped_aiguiller = core.get_fuped_aiguiller()
         customers_aiguiller = [
-            customer['name']
+            customer['name'].lower()
             for customer in fuped_aiguiller
         ]
         customers_si = core.get_customers_si()
+        print("customers in database: {}".format(len(customers_si)))
         customers_si = [customer['name'] for customer in customers_si]
+        print(customers_si)
 
         common_customers = set(customers_aiguiller) & set(customers_si)
         unfuped = [
